/*
    This file is part of Vimoware.

    Vimoware is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Vimoware is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Vimoware. If not, see <http://www.gnu.org/licenses/>.
 */
package at.ac.tuwien.vitalab.middleware;

import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.Socket;
import java.net.URL;
import java.util.Vector;

import org.ksoap2.serialization.SoapObject;

import edu.wustl.mobilab.sliver.log.Logger;
import edu.wustl.mobilab.sliver.log.LoggerFactory;
import edu.wustl.mobilab.sliver.soap.Channel;
import edu.wustl.mobilab.sliver.soap.j2se.HTTPChannel;
import edu.wustl.mobilab.sliver.soap.j2se.SocketChannel;

/**
 * Deploys Web Services on the middleware from outside.
 * 
 * @author Lukasz Juszczyk
 *
 */
public class WSDeployer {

	private static Logger logger=LoggerFactory.getLogger(WSDeployer.class);
	
	private static String confDeploymentNS;
	
	/**
	 * Main function.
	 * 
	 * @param args Arguments.
	 * 
	 * @throws Exception If errors occur while deploying/undeploying.
	 */
	public static void main(String[] args) throws Exception {
		if (args.length<2) {
			printUsage();
			System.exit(1);
		}
		
		SoapObject soapObject=null;
		
		confDeploymentNS=MiddlewareConfiguration.getSoapDeploymentNS();
		
		if ("deploy".equals(args[0])) {
			soapObject=new SoapObject(confDeploymentNS,"deploy");
			
			soapObject.addProperty("className", args[1]);
			
			Vector jarPaths=new Vector();
			
			for (int i=2;i<args.length;i++) {
				jarPaths.add(args[i]);
			}
			
			soapObject.addProperty("jarPaths", jarPaths);
						
		} else if ("undeploy".equals(args[0])) {
			soapObject=new SoapObject(confDeploymentNS,"undeploy");
			
			soapObject.addProperty("className", args[1]);
			
		} else {
			printUsage();
			System.exit(1);
		}

		Channel channel=getChannel();		
		channel.call(soapObject);		// invocation	
		channel.close();
		
	}
	
	/**
	 * Returns the proper channel, regarding the configuration file.
	 * 
	 * @return Channel for SOAP calls.
	 * @throws IOException If IO errors occur.
	 */
	private static Channel getChannel() throws IOException {

		int confPort=MiddlewareConfiguration.getSoapPort();
		String confTransport=MiddlewareConfiguration.getSoapTransportType();
		String myIP=MiddlewareConfiguration.getIP();
		
		Channel channel=null;
		
		// which channel shall be created? socket or http?
		if (confTransport.toLowerCase().equals(
				MiddlewareConfiguration.TRANSPORT_SOCKET)) {
			
			Socket socket=new Socket(myIP,confPort);			
			channel=new SocketChannel(socket);
			
		} else  {

			String confServicePath=MiddlewareConfiguration.getHttpServicePath();

			HttpURLConnection connection=(HttpURLConnection)new URL(
					"http://"+myIP+":"+confPort+confServicePath+"/").
					openConnection();
			
			channel=new HTTPChannel(connection,confDeploymentNS);			
		}		
		
		return channel;
	}
	
	/**
	 * Prints how to use this tool.
	 *
	 */
	private static void printUsage() {
		System.err.println("usage: "+WSDeployer.class.getName()+
				" deploy <classname> [jarfile ...]");
		System.err.println("or   : "+WSDeployer.class.getName()+
				" undeploy <classname>");
	}

}
