/*
    This file is part of Vimoware.

    Vimoware is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Vimoware is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Vimoware. If not, see <http://www.gnu.org/licenses/>.
 */
package at.ac.tuwien.vitalab.middleware.discovery;

import java.util.Hashtable;

import at.ac.tuwien.vitalab.middleware.MiddlewareConfiguration;
import at.ac.tuwien.vitalab.middleware.AWebService;
import at.ac.tuwien.vitalab.middleware.soap.ServiceContainer;

/**
 * Retrieves all necessary attributes of a Web service for SLP publication.
 * 
 * @author Lukasz Juszczyk
 *
 */
public class AttributeRetriever {

	/**
	 * Retrieves all necessary attributes of a Web service for SLP publication.
	 * 
	 * @param ws Web service.
	 * @return Hashtable with attributes.
	 */
	public static Hashtable getAttributes(AWebService ws) {
		Hashtable result=new Hashtable();
		
		ServiceContainer container=ServiceContainer.getLocalServiceContainer();

		try {
			result.putAll(ws.getAttributes());			
		} catch (NullPointerException npe) {
			// if the service returns null, ignore it...
		}
		
		if (container!=null) {
			result.put(ServiceInfo.URL, container.getServiceURL());
		}

		result.put(ServiceInfo.NAMESPACE, ws.getServiceNamespace());			
		
		result.put(ServiceInfo.ID, ws.getServiceID());
		
		result.put(ServiceInfo.HOSTID,MiddlewareConfiguration.getHostUUID());
		
		return result;
	}
	
}
