/*
    This file is part of Vimoware.

    Vimoware is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Vimoware is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Vimoware. If not, see <http://www.gnu.org/licenses/>.
 */
package at.ac.tuwien.vitalab.middleware.soap.header;

import java.util.Hashtable;
import java.util.NoSuchElementException;

import org.kxml2.kdom.Element;
import org.xmlpull.v1.XmlPullParserException;

import com.eaio.uuid.UUID;

/**
 * MessageID header element.
 * 
 * @author Lukasz Juszczyk
 *
 */
public class MessageIDHeader extends AHeaderElement {

	private String messageID=new UUID().toString();

	protected static Element idElement=new Element();
	
	static {
		idElement.setName("MessageID");
		idElement.setNamespace(SoapHeaders.WSA_NAMESPACE);
	}
	
	/**
	 * Constructor.
	 *
	 */
	public MessageIDHeader() {
		super(idElement.getName(),idElement.getNamespace());
	}

	/**
	 * Constructor, reading in the element from the SOAP headers.
	 * 
	 * @param headers XML header elements.
	 * @throws NoSuchElementException If the SOAP headers do not contain it.
	 * @throws XmlPullParserException If the header is malformed.
	 */
	public MessageIDHeader(Element[] headers) 
	throws NoSuchElementException, XmlPullParserException {
		this();
		this.load(headers);
	}

	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.soap.AHeaderElement#getNamespaceMap()
	 */
	public Hashtable getNamespaceMap() {
		Hashtable result=new Hashtable();
		result.put("wsa", SoapHeaders.WSA_NAMESPACE);
		return result;
	}

	/*
	 * (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.soap.AHeaderElement#load(org.kxml2.kdom.Element)
	 */
	public void load(Element el) throws XmlPullParserException {
		if (!this.hasSameName(idElement, el)) {
			throw new IllegalArgumentException(
					"Not a valid MessageID element.");
		}
		messageID=el.getText(0);
		if (messageID==null) {
			throw new XmlPullParserException("Message ID missing.");
		}
		if (messageID.startsWith("uuid:")) {
			messageID=messageID.substring(5);
		}
	}

	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.soap.AHeaderElement#toXML()
	 */
	public Element toXML() {
		Element messageIDEl=this.createWithSameName(idElement);
		
		if (messageID.startsWith("uuid:")) {
			messageIDEl.addChild(Element.TEXT,messageID);				
		} else {
			messageIDEl.addChild(Element.TEXT,"uuid:"+messageID);
		}
		
		return messageIDEl;
	}
	
	/**
	 * Returns the message ID.
	 * 
	 * @return Message ID.
	 */
	public String getMessageID() {
		return messageID;
	}
	
}
