/*
    This file is part of Vimoware.

    Vimoware is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Vimoware is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Vimoware. If not, see <http://www.gnu.org/licenses/>.
 */
package at.ac.tuwien.vitalab.middleware.soap.header;

import java.util.Hashtable;
import java.util.NoSuchElementException;

import org.kxml2.kdom.Element;
import org.xmlpull.v1.XmlPullParserException;

/**
 * To header element.
 * 
 * @author Lukasz Juszczyk
 *
 */
public class RecipientIDHeader extends AHeaderElement {

	protected String hostUUID;
	
	protected static Element toElement=new Element();
	
	static {
		toElement.setName("RecipientID");
		toElement.setNamespace(SoapHeaders.MWA_NAMESPACE);
	}
	
	/**
	 * Constructor.
	 *
	 */
	protected RecipientIDHeader() {
		super(toElement.getName(),toElement.getNamespace());
	}

	/**
	 * Constructor, reading in the element from the SOAP headers.
	 * 
	 * @param headers XML header elements.
	 * @throws NoSuchElementException If the SOAP headers do not contain it.
	 * @throws XmlPullParserException If the header is malformed.
	 */
	public RecipientIDHeader(Element[] headers) 
	throws NoSuchElementException, XmlPullParserException {
		this();
		this.load(headers);
	}
	
	/**
	 * Constructor.
	 * 
	 * @param hostUUID Host UUID.
	 */
	public RecipientIDHeader(String hostUUID) {
		this();
		setHostID(hostUUID);
	}
	
	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.soap.header.AHeaderElement#load(org.kxml2.kdom.Element)
	 */
	public void load(Element el) throws XmlPullParserException {
		
		if (!this.hasSameName(toElement, el)) {
			throw new IllegalArgumentException(
					"Not a valid To element.");
		}
		hostUUID=el.getText(0);
		if (hostUUID==null) {
			throw new XmlPullParserException("Host ID missing.");
		}
		if (hostUUID.startsWith("uuid:")) {
			hostUUID=hostUUID.substring(5);
		}
	}

	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.soap.header.AHeaderElement#toXML()
	 */
	public Element toXML() {

		Element toEl=this.createWithSameName(toElement);
		
		if (hostUUID.startsWith("uuid:")) {
			toEl.addChild(Element.TEXT,hostUUID);				
		} else {
			toEl.addChild(Element.TEXT,"uuid:"+hostUUID);
		}
		
		return toEl;
	}
	
	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.soap.header.AHeaderElement#getNamespaceMap()
	 */
	public Hashtable getNamespaceMap() {
		Hashtable result=new Hashtable();
		result.put("wma", SoapHeaders.MWA_NAMESPACE);
		return result;
	}

	/**
	 * Sets the Host ID.
	 * 
	 * @param hostID Host ID.
	 */
	public void setHostID(String hostID) {
		this.hostUUID=hostID;
	}
	
	/**
	 * Returns the Host ID.
	 * 
	 * @return Host ID.
	 */
	public String getHostID() {
		return hostUUID;
	}
}
