/*
    This file is part of Vimoware.

    Vimoware is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Vimoware is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Vimoware. If not, see <http://www.gnu.org/licenses/>.
 */
package at.ac.tuwien.vitalab.middleware.soap.services;

import java.util.Collection;
import java.util.Hashtable;
import java.util.Vector;

import edu.wustl.mobilab.sliver.soap.SOAPServer.InvocationContext;

import at.ac.tuwien.vitalab.middleware.AWebService;
import at.ac.tuwien.vitalab.middleware.Middleware;
import at.ac.tuwien.vitalab.middleware.discovery.ICallbackReceiver;
import at.ac.tuwien.vitalab.middleware.soap.SoapResponse;
import at.ac.tuwien.vitalab.middleware.soap.header.RelatesToHeader;

/**
 * Callback service for asynchronous responses.
 * 
 * @author Lukasz Juszczyk
 *
 */
public class CallbackService extends AWebService {

	public static final String NAME="CallbackService";
	
	public static final String NAMESPACE=Middleware.NAMESPACE+"callback/";
	
	private static Hashtable callbacks=new Hashtable();
	
	
	/**
	 * Constructor.
	 *
	 */
	public CallbackService() {
		super(NAME,NAMESPACE);
	}
	
	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.AWebService#getAttributes()
	 */
	public Hashtable getAttributes() {
		return new Hashtable();
	}

	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.AWebService#getConfigurationRessourceName()
	 */
	public String getConfigurationRessourceName() {
		return null;
	}

	/**
	 * Web service method for receiving callbacks.
	 * 
	 * @param context Invocation context for retrieving the related message ID.
	 * @param response The response of the invocation.
	 * @throws Exception If the request does not contain all necessary
	 * SOAP headers.
	 */
	public void callback(InvocationContext context, Object response) 
	throws Exception {
		
		RelatesToHeader relatesTo=new RelatesToHeader(
					context.incomingChannel.getIncomingXMLHeaders());
			
		String messageID=relatesTo.getRelatedMessageID();
		
		final ICallbackReceiver receiver=
			(ICallbackReceiver)callbacks.remove(messageID);
		
		if (receiver==null) {
			throw new IllegalArgumentException(
					"Unknown/outdated related message ID.");
		}

		try {
			// if the result came in a soap response, extract it
			response=SoapResponse.retrieveResultObject(response);
		} catch (IllegalArgumentException iae) {
			// otherwise ignore it
		}

		try {
			SoapResponse.checkForFault(response);
		} catch (at.ac.tuwien.vitalab.middleware.soap.SoapFault sf) {
			receiver.error(messageID, sf);
			return;
		}
		
		receiver.callback(messageID, response);		
	}
	
	/**
	 * Regeisters a callback.
	 * 
	 * @param messageID MessageID it is related to.
	 * @param callbackReceiver Callback receiver.
	 */
	public void register(String messageID, ICallbackReceiver callbackReceiver) {
		callbacks.put(messageID, callbackReceiver);
	}

	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.AWebService#getOperationNames()
	 */
	public Collection getOperationNames() {
		Vector names=new Vector();
		names.add("callback");
		return names;
	}

	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.AWebService#getOperationDescription(java.lang.String)
	 */
	public Hashtable getOperationDescription(String operationName) {
		if ("callback".equals(operationName)) {
			return new Hashtable();
		} 
		throw new IllegalArgumentException("Invalid operation name.");
	}
	
}
