/*
    This file is part of Vimoware.

    Vimoware is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Vimoware is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Vimoware. If not, see <http://www.gnu.org/licenses/>.
 */
package demo;

import java.util.Collection;
import java.util.Date;
import java.util.Hashtable;
import java.util.Vector;

import at.ac.tuwien.vitalab.middleware.AWebService;

/**
 * Simple service which provides one operation "getDate", which returns
 * the current timestamp as a string.
 * 
 * @author Lukasz Juszczyk
 *
 */
public class DemoService extends AWebService {

	// constructor
	public DemoService() {
		super("demoService","http://www.vitalab.tuwien.ac.at/demoservice");
	}
	
	// deployment hook
	public void onDeploy() {
		System.out.println("deploying "+getServiceID());
	}

	// undeployment hook
	public void onUndeploy() {
		System.out.println("undeploying "+getServiceID());
	}

	// web service operation delivering the date string
	public String getDate() {
		return ""+new Date();
	}
	
	// additional attributes published by slp
	public Hashtable getAttributes() {
		Hashtable result=new Hashtable();
		result.put("somekey", "some value");
		return result;
	}

	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.AWebService#getConfigurationRessourceName()
	 */
	public String getConfigurationRessourceName() {
		return null;
	}

	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.AWebService#getOperationNames()
	 */	
	public Collection getOperationNames() {
		Vector names=new Vector();
		names.add("getDate");
		return names;
	}

	/* (non-Javadoc)
	 * @see at.ac.tuwien.vitalab.middleware.AWebService#getOperationDescription(java.lang.String)
	 */
	public Hashtable getOperationDescription(String operationName) {
		if ("getDate".equals(operationName)) {
			return new Hashtable();
		} 
		throw new IllegalArgumentException("Invalid operation name.");
	}
	
}
